@@ -12,7 +12,7 @@ __all__ = (
 
 class CommandContext(DiscordMessage):
 
-    def __init__(self, data: Union[dict, SimpleNamespace], client: HttpClient):
+    def __init__(self, data: Union[dict, object], client: HttpClient):
         super().__init__(data, client)
         self.api = client
 
