@@ -1,5 +1,8 @@
+import random
 from enum import Enum
 
+from typing_extensions import Self
+
 Events: list[str] = ['ready', '']
 
 
@@ -31,7 +34,17 @@ class Intents(Enum):  # Discord intents
 
 class ChannelType(Enum):
     TextChannel: int = 0
+    DirectChannel: int = 1
     VoiceChannel: int = 2
+    GroupChannel: int = 3
+    CategoryChannel: int = 4
+    AnnouncementChannel: int = 5
+    AnnouncementThread: int = 10
+    PublicThread: int = 11
+    PrivateThread: int = 12
+    StageChannel: int = 13
+    GuildDirectory: int = 14
+    ForumChannel: int = 15
 
 
 class Color(Enum):
@@ -45,3 +58,7 @@ class Color(Enum):
     Gold: int = 0xeb8c26
     Purple: int = 0xb024f1
     Pink: int = 0xff2ebd
+
+    @classmethod
+    def random(cls) -> Self:
+        return random.choice(list(cls))
